@@ -4,7 +4,7 @@
 # Date:    25-Jun-2021
 #
 # Updates:
-#
+#   3-Mar-2023 Standard args passed into workflow
 ##
 """
 Execution workflow for protein target data ETL operations.
@@ -31,16 +31,30 @@ HERE = os.path.abspath(os.path.dirname(__file__))
 
 
 class ProteinTargetSequenceExecutionWorkflow(object):
-    def __init__(self):
-        self.__mockTopPath = None
-        configPath = os.path.join(HERE, "exdb-config-example.yml")
-        configName = "site_info_remote_configuration"
-        self.__cfgOb = ConfigUtil(configPath=configPath, defaultSectionName=configName, mockTopPath=self.__mockTopPath)
-        self.__cachePath = os.path.join(HERE, "CACHE")
+    def __init__(self, **kwargs):
+        """Workflow wrapper  --  Workflow to rebuild and stash "buildable" cache resources.
+
+        kwargs:
+            configPath (str, optional): path to configuration file (default: 'exdb-config-example.yml')
+            configName (str, optional): configuration section name (default: 'site_info_configuration')
+            workPath (str, optional):  path to working directory (default: HERE)
+            stashRemotePrefix (str, optional): file name prefix (channel) applied to remote stash file artifacts (default: None)
+        """
+        configPath = kwargs.get("configPath", "exdb-config-example.yml")
+        self.__configName = kwargs.get("configName", "site_info_configuration")
+        mockTopPath = kwargs.get("mockTopPath", None)
+        self.__cfgOb = ConfigUtil(configPath=configPath, defaultSectionName=self.__configName, mockTopPath=mockTopPath)
+        self.__workPath = kwargs.get("workPath", HERE)
+        self.__cachePath = os.path.join(self.__workPath, "CACHE")
         #
-        self.__remotePrefix = None
+        self.__stashRemotePrefix = kwargs.get("stashRemotePrefix", None)
+        #
+        self.__debugFlag = kwargs.get("debugFlag", False)
         self.__startTime = time.time()
-        logger.info("Starting at %s", time.strftime("%Y %m %d %H:%M:%S", time.localtime()))
+        if self.__debugFlag:
+            logger.setLevel(logging.DEBUG)
+            logger.debug("Starting at %s", time.strftime("%Y %m %d %H:%M:%S", time.localtime()))
+        #
 
     def resourceCheck(self):
         unitS = "MB" if platform.system() == "Darwin" else "GB"
@@ -148,7 +162,13 @@ class ProteinTargetSequenceExecutionWorkflow(object):
         ok = False
         try:
             ptsW = ProteinTargetSequenceWorkflow(self.__cfgOb, self.__cachePath)
-            ok = ptsW.buildFeatureData(referenceResourceName="pdbprent", resourceNameList=["sabdab", "card", "imgt"], useTaxonomy=True, backup=True, remotePrefix=self.__remotePrefix)
+            ok = ptsW.buildFeatureData(
+                referenceResourceName="pdbprent",
+                resourceNameList=["sabdab", "card", "imgt"],
+                useTaxonomy=True,
+                backup=True,
+                remotePrefix=self.__stashRemotePrefix
+            )
         except Exception as e:
             logger.exception("Failing with %s", str(e))
         return ok
@@ -158,7 +178,7 @@ class ProteinTargetSequenceExecutionWorkflow(object):
         ok = False
         try:
             ptsW = ProteinTargetSequenceWorkflow(self.__cfgOb, self.__cachePath)
-            ok = ptsW.buildActivityData(referenceResourceName="pdbprent", resourceNameList=["chembl", "pharos"], backup=True, remotePrefix=self.__remotePrefix)
+            ok = ptsW.buildActivityData(referenceResourceName="pdbprent", resourceNameList=["chembl", "pharos"], backup=True, remotePrefix=self.__stashRemotePrefix)
         except Exception as e:
             logger.exception("Failing with %s", str(e))
         return ok
@@ -168,7 +188,7 @@ class ProteinTargetSequenceExecutionWorkflow(object):
         ok = False
         try:
             ptsW = ProteinTargetSequenceWorkflow(self.__cfgOb, self.__cachePath)
-            ok = ptsW.buildCofactorData(referenceResourceName="pdbprent", resourceNameList=["chembl", "pharos", "drugbank"], backup=True, remotePrefix=self.__remotePrefix)
+            ok = ptsW.buildCofactorData(referenceResourceName="pdbprent", resourceNameList=["chembl", "pharos", "drugbank"], backup=True, remotePrefix=self.__stashRemotePrefix)
         except Exception as e:
             logger.exception("Failing with %s", str(e))
         return ok
@@ -182,7 +202,7 @@ def fullWorkflow():
     ptsWf = ProteinTargetSequenceExecutionWorkflow()
     ok = True
     ok = ptsWf.cacheTaxonomy()
-    ok = ptsWf.fetchUniProtTaxonomy()
+    ok = ptsWf.updateUniProtTaxonomy()
     ok = ptsWf.fetchProteinEntityData() and ok
     ok = ptsWf.fetchChemicalReferenceMappingData() and ok
     ok = ptsWf.fetchLigandNeighborMappingData() and ok
